<?php $TRANSLATIONS = array(
"Music" => "Müzik",
"songs" => "şarkılar",
"albums" => "albümler",
"Add to playlist" => "Çalma listesine ekle",
"Add album to playlist" => "Albümü çalma listesine ekle",
"Play" => "Oynat",
"Pause" => "Beklet",
"Previous" => "Önceki",
"Next" => "Sonraki",
"Mute" => "Sesi kapat",
"Unmute" => "Sesi aç",
"Rescan Collection" => "Koleksiyonu Tara",
"Artist" => "Sanatç",
"Album" => "Albüm",
"Title" => "Başlık"
);
